@@ -584,15 +584,10 @@ def cmd_install(manager, args, config, configfile):
                                            default_to_yes=False):
                     return
 
-    join_timeout = 0.01
-    tick_interval = 1
-
     installs_failed = []
 
     for info, version, _ in sorted(package_infos, key=lambda x: x[0].package.name):
         name = info.package.qualified_name()
-        time_accumulator = 0
-        tick_count = 0
 
         is_overwriting = False
         ipkg = manager.find_installed_package(name)
@@ -606,23 +601,19 @@ def cmd_install(manager, args, config, configfile):
 
         worker = InstallWorker(manager, name, version)
         worker.start()
+        print('Installing "{}"'.format(name), end='')
+        sys.stdout.flush()
 
-        while worker.is_alive():
-            worker.join(join_timeout)
-            time_accumulator += join_timeout
+        while True:
+            worker.join(1.0)
 
-            if time_accumulator >= tick_interval:
-                if tick_count == 0:
-                    print('Installing "{}"'.format(name), end='')
-                else:
-                    print('.', end='')
+            if not worker.is_alive():
+                break
 
-                sys.stdout.flush()
-                tick_count += 1
-                time_accumulator -= tick_interval
+            print('.', end='')
+            sys.stdout.flush()
 
-        if tick_count != 0:
-            print('')
+        print('')
 
         if worker.error:
             print('Failed installing "{}": {}'.format(name, worker.error))
@@ -968,7 +959,8 @@ def cmd_remove(manager, args, config, configfile):
                 dep_listing += '  {}\n'.format(_name)
 
             if dep_listing:
-                print('The following installed packages (or more) will be unloaded as well.')
+                print('The following installed packages were dependent on the '
+                      'removed package(s) and will be UNLOADED.')
                 print(dep_listing)
 
             if not args.force and not confirmation_prompt('Proceed?', default_to_yes=False):
@@ -1072,8 +1064,15 @@ def cmd_refresh(manager, args, config, configfile):
         src_pkgs_before = {i.qualified_name()
                            for i in manager.source_packages()}
 
-        error = manager.refresh_source(
-            source, aggregate=args.aggregate, push=args.push)
+        error = ''
+        aggregation_issues = []
+
+        if args.aggregate:
+            res = manager.aggregate_source(source, args.push)
+            error = res.refresh_error
+            aggregation_issues = res.package_issues
+        else:
+            error = manager.refresh_source(source, False, args.push)
 
         if error:
             had_failure = True
@@ -1095,7 +1094,14 @@ def cmd_refresh(manager, args, config, configfile):
                 print('\t\t{} {}'.format(change, name))
 
         if args.aggregate:
-            print('\tMetadata aggregated')
+            if aggregation_issues:
+                print('\tWARNING: Metadata aggregated, but excludes the '
+                      'following packages due to described problems:')
+
+                for url, issue in aggregation_issues:
+                    print('\t\t{}: {}'.format(url, issue))
+            else:
+                print('\tMetadata aggregated')
 
         if args.push:
             print('\tPushed aggregated metadata')
@@ -2399,7 +2405,7 @@ def main():
             zeekpkg.LOG.setLevel(logging.WARNING)
         elif args.verbose == 2:
             zeekpkg.LOG.setLevel(logging.INFO)
-        elif args.verbose == 3:
+        elif args.verbose >= 3:
             zeekpkg.LOG.setLevel(logging.DEBUG)
 
         zeekpkg.LOG.addHandler(handler)
